@@ -10,7 +10,7 @@ Nagios::NRPE - A Nagios NRPE implementation in pure perl
  my $client = Nagios::NRPE::Client->new( host => "localhost", check => 'check_cpu');
  my $response = $client->run();
  if(defined $response->{error}) {
-   print "ERROR: Couldn't run check ".$client->check()." because of: "$response->{reason}."\n";
+   print "ERROR: Couldn't run check ".$client->check()." because of: ".$response->{reason}."\n";
  } else {
    print $response->{status}."\n";
  }
@@ -35,11 +35,11 @@ Nagios::NRPE - A Nagios NRPE implementation in pure perl
                     Proto    => 'tcp',
                     Type     => SOCK_STREAM) or die "ERROR: $@ \n";
 
- print $socket $packet->assemble(type => QUERY_PACKET,
+ print $socket $packet->assemble(type => NRPE_PACKET_QUERY,
                               buffer => "check_load 1 2 3",
                               version => NRPE_PACKET_VERSION_3 );
 
- my $data = <$socket>
+ my $data = <$socket>;
  my $response = $packet->disassemble($data);
 
  print $response->{buffer};
@@ -47,11 +47,11 @@ Nagios::NRPE - A Nagios NRPE implementation in pure perl
 =head1 DESCRIPTION
 
 This file currently only serves as a stub so Build.PL will find it. For more information on
-the submodules please read Nagios::NRPE::Client or Nagios::NRPE::Packet or Nagios::NRPE::Daemon.
+the submodules please read L<Nagios::NRPE::Client> or L<Nagios::NRPE::Packet> or L<Nagios::NRPE::Daemon>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013-2018 by the authors (see AUTHORS file).
+This software is copyright (c) 2013-2018 by the authors (see L<AUTHORS|https://github.com/stockholmuniversity/Nagios-NRPE/blob/master/AUTHORS> file).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -63,6 +63,6 @@ package Nagios::NRPE;
 use strict;
 use warnings;
 
-our $VERSION = '2.0.9';
+our $VERSION = '2.0.11';
 
 1;
