@@ -23,11 +23,11 @@ Nagios::NRPE::Packet - Assembly and disassembly of an NRPE packet
                     Proto    => 'tcp',
                     Type     => SOCK_STREAM) or die "ERROR: $@ \n";
 
- print $socket $packet->assemble(type => QUERY_PACKET,
+ print $socket $packet->assemble(type => NRPE_PACKET_QUERY,
                               buffer => "check_load 1 2 3",
                               version => NRPE_PACKET_VERSION_3 );
 
- my $data = <$socket>
+ my $data = <$socket>;
  my $response = $packet->disassemble($data);
 
  print $response->{buffer};
@@ -74,7 +74,7 @@ See CONSTANTS for options here.
 
 The TYPE of packet you wish to send, which is either QUERY or RESPONSE.
 
-See CONSTANTS for options here.
+See L</CONSTANTS> for options here.
 
  * result_code
 
@@ -147,8 +147,8 @@ These constants can be exported upon request with the 'use' pragma like this:
 
 The value of the NRPE version you want/need to use.
 
-=item * QUERY_PACKET
-        RESPONSE_PACKET
+=item * NRPE_PACKET_QUERY
+        NRPE_PACKET_RESPONSE
 
 The packet type you want to send or recieve
 
@@ -177,7 +177,7 @@ States returned by the check
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013-2018 by the authors (see AUTHORS file).
+This software is copyright (c) 2013-2018 by the authors (see L<AUTHORS|https://github.com/stockholmuniversity/Nagios-NRPE/blob/master/AUTHORS> file).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -186,7 +186,7 @@ the same terms as the Perl 5 programming language system itself.
 
 package Nagios::NRPE::Packet;
 
-our $VERSION = '2.0.9';
+our $VERSION = '2.0.11';
 
 use 5.010_000;
 require Exporter;
